:mod:`xoutil.deprecation` - Utils for marking deprecated elements
=================================================================

.. automodule:: xoutil.deprecation

.. autofunction:: deprecated(replacement, msg=None, deprecated_module=None, removed_in_version=None, check_version=False)
